@@ -1,6 +1,8 @@
 from typing import Callable, Any
 
+import rx
 from rx import Observable
+from rx import operators as ops
 
 from interstate_py.interstate_server import InterstateServer
 from interstate_py.log_factory import LogFactory
@@ -26,7 +28,7 @@ class Interstate:
             :return:
             """
             try:
-                transformer(Observable.empty())
+                transformer(rx.empty())
                 return transformer
             except Exception as e:
                 Interstate._log.error(
@@ -42,7 +44,7 @@ class Interstate:
     def request_response_server(req_res_handler: Callable[[Any], Any], port: int = 8077,
                                 serialization: Serialization = PassthroughSerialization()) -> InterstateServer:
         def transformer(obs: Observable) -> Observable:
-            return obs.map(req_res_handler)
+            return obs.pipe(ops.map(req_res_handler))
 
         server = AIOZMQServer(port, transformer, serialization)
         server.start_server()
@@ -53,7 +55,7 @@ class Interstate:
     def request_stream(req_stream: Callable[[Any], Observable], port: int = 8077,
                        serialization: Serialization = PassthroughSerialization()) -> InterstateServer:
         def transformer(obs: Observable) -> Observable:
-            return obs.flat_map(req_stream)
+            return obs.pipe(ops.flat_map(req_stream))
 
         server = AIOZMQServer(port, transformer, serialization)
         server.start_server()
