@@ -1,13 +1,15 @@
 import asyncio
 from asyncio import Queue
 from concurrent.futures.thread import ThreadPoolExecutor
+from typing import Any
 
 import janus
+from rx.internal import DisposedException
 
 from interstate_py.connection_agent import ConnectionAgentBase
 from interstate_py.control.worker_task import AIOWorkerTask
 from interstate_py.error.error_assembly import ErrorAssembly
-from interstate_py.interstate_message import InterstateWireMessageType
+from interstate_py.interstate_message import InterstateWireMessageType, InterstateWireMessage
 from interstate_py.log_factory import LogFactory
 from interstate_py.multiplex_message import MultiplexMessage
 from interstate_py.serialization.serialization import Serialization
@@ -37,25 +39,30 @@ class StreamDemultiplexer(AIOWorkerTask):
         identity = message.identity.decode()
         connection = self._con_agent.get(identity)
 
-        def _send(connection: StreamConnection, payload):
-            self._log.debug("Sending payload to subject")
-            connection.inbound_stream().on_next(payload)
-            self._log.debug("Payload sent to subject")
+        def _dispatch(connection: StreamConnection, payload):
+            try:
+                self._log.debug("Sending payload to subject")
+                connection.inbound_stream().on_next(payload)
+                self._log.debug("Payload sent to subject")
+            except DisposedException:
+                self._log.warn("Connection (%s) has already been disposed but not garbage collected", identity)
+                connection.close_inbound()
+                connection.close_outbound()
+                self._con_agent.dump(connection.identity())
+            except Exception as e:
+                self._log.warn("Calling on_next produced an exception: %s", ErrorAssembly.exc_message(e))
+                self._outbound_queue.sync_q.put(
+                    MultiplexMessage(message.identity.decode(), InterstateWireMessageType.ERROR,
+                                     ErrorAssembly.to_error(ErrorAssembly.GENERAL,
+                                                            e)))
 
         if message.type == InterstateWireMessageType.NEXT:
             self._log.debug("[IN][NEXT] - {}".format(message))
-            try:
-                deserialized_payload = self._serialization.deserialize(message.payload)
-                asyncio.get_event_loop().run_in_executor(self._pool, #TODO: configurable
-                                                               _send,
-                                                               connection,
-                                                               deserialized_payload)
-            except Exception as e:
-                self._log.warn("[IN][NEXT] - Could not deserialize incoming message: %s", ErrorAssembly.exc_message(e))
-                await self._outbound_queue.async_q.put(
-                    MultiplexMessage(message.identity.decode(), InterstateWireMessageType.ERROR,
-                                     ErrorAssembly.to_error(ErrorAssembly.DESERIALIZATION_ERROR_TYPE,
-                                                            e)))
+            asyncio.get_event_loop().run_in_executor(self._pool,  # TODO: configurable
+                                                     _dispatch,
+                                                     connection,
+                                                     self._deserialize(message))
+
         elif message.type == InterstateWireMessageType.ERROR:
             self._log.warn("[IN][ERROR] - {}".format(message))
             connection.inbound_stream().on_error(Exception("Error"))
@@ -65,10 +72,20 @@ class StreamDemultiplexer(AIOWorkerTask):
             connection.inbound_stream().on_completed()
             connection.close_inbound()
         elif message.type == InterstateWireMessageType.PING:
-            # TODO: find a better way via interceptors or another mechanism
             self._log.debug("[IN][PING] - {}".format(message))
-            await self._outbound_queue.async_q.put(MultiplexMessage(identity, InterstateWireMessageType.PONG, "pong".encode()))
+            await self._outbound_queue.async_q.put(
+                MultiplexMessage(identity, InterstateWireMessageType.PONG, "pong".encode()))
         else:
             self._log.warn("Can not handle message: {}".format(message))
 
         self._raw_inbound_queue.task_done()
+
+    async def _deserialize(self, message: InterstateWireMessage) -> Any:
+        try:
+            return self._serialization.deserialize(message.payload)
+        except Exception as e:
+            self._log.warn("[IN][NEXT] - Could not deserialize incoming message: %s", ErrorAssembly.exc_message(e))
+            await self._outbound_queue.async_q.put(
+                MultiplexMessage(message.identity.decode(), InterstateWireMessageType.ERROR,
+                                 ErrorAssembly.to_error(ErrorAssembly.DESERIALIZATION_ERROR_TYPE,
+                                                        e)))
