@@ -23,6 +23,6 @@ class InboundWorker(AIOWorkerTask):
             zmsg = await self._router.read()
             wire_message = ZMsgAssembly.disassemble(zmsg)
             await self._inbound_queue.put(wire_message)
-            self._log.info("Dispatched inbound message to queue")
+            self._log.debug("Dispatched inbound message to queue")
         except Exception as e:
             self._log.error(e)
